@@ -6,7 +6,7 @@ use warnings;
 our $VERSION;
 
 BEGIN {
-    $VERSION = '0.14';
+    $VERSION = '0.15';
 }
 
 =encoding utf-8
@@ -268,6 +268,7 @@ sub use_event {
     }
 }
 
+# called from XS
 sub _convert_to_our_promise {
     my $thenable = shift;
     my $deferred= Promise::XS::Deferred::create();
@@ -297,10 +298,6 @@ sub _convert_to_our_promise {
     return $deferred->promise;
 }
 
-Promise::XS::Deferred::___set_conversion_helper(
-    \&_convert_to_our_promise,
-);
-
 #----------------------------------------------------------------------
 # Aggregator functions
 sub all {
